import React, {Component} from 'react'
import PropTypes from 'prop-types'
import { Form, Row, Col, Input, notification } from 'antd'
import './index.scss'

const { TextArea } = Input

class MainSearch extends Component {
  static propTpyes = {
    inputSubmit: PropTypes.func // 回车事件
  }

  componentDidMount () {
    try {
      let _form = document.getElementById('config')
      if (_form && _form.select) {
        _form.select()
      }
    } catch (e) {
      console.warn('Form focusing error！')
    }
  }

  handleConfirm = () => {
    // 表单提交时检查输入值是否正确
    return new Promise((resolve, reject) => {
      this.props.form.validateFieldsAndScroll((err, values) => {
        if (!err) {
          let _config = values.config.replace(/(\n|\s)+/g, '')

          if (!_config) {
            notification.warning({
              top: 92,
              message: '请输入配置信息',
              duration: 5
            })
            reject()
            return
          }
          try {
            _config = JSON.parse(window.decodeURIComponent(window.atob(_config)))

            if (typeof(_config) === 'object' && _config.$srcId) {
              let srcid = localStorage.getItem(window.GLOB.sysSign + 'srcId')
              if (srcid && _config.$srcId !== srcid) {
                notification.warning({
                  top: 92,
                  message: '当前系统无权限使用此项配置！',
                  duration: 5
                })

                _config = ''
              } else {
                delete _config.$srcId
              }
            }
          } catch (e) {
            // 通过sql语句添加字段集
            if (/[a-zA-Z0-9_]+\s+(nvarchar\(\d+\)|Decimal\(18,\d+\)|Int|datetime|date)/ig.test(values.config)) {
              _config = {
                key: 'datasourcefield',
                type: 'array',
                data: []
              }

              let list = values.config.match(/[a-zA-Z0-9_]+\s+(nvarchar\(\d+\)|Decimal\(18,\d+\)|Int|datetime|date)/ig)

              list.forEach(item => {
                _config.data.unshift({
                  datatype: item.split(/\s+/)[1],
                  field: item.split(/\s+/)[0],
                  label: item.split(/\s+/)[0],
                })
              })
            } else {
              notification.warning({
                top: 92,
                message: '解析错误',
                duration: 5
              })
              _config = ''
            }
          }

          if (_config) {
            resolve(_config)
          }
        } else {
          reject(err)
        }
      })
    })
  }

  enterPress = (e) => {
    e.stopPropagation()

    setTimeout(() => {
      this.props.inputSubmit && this.props.inputSubmit()
    }, 200)
  }

  render() {
    const { getFieldDecorator } = this.props.form
    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 24 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 24 }
      }
    }
    return (
      <Form {...formItemLayout} className="config-paste-form">
        <Row gutter={24}>
          <Col span={24}>
            <Form.Item label="" className="textarea">
              {getFieldDecorator('config', {
                initialValue: '',
                rules: [
                  {
                    required: true,
                    message: '请输入配置信息!'
                  }
                ]
              })(<TextArea autoSize={{ minRows: 6, maxRows: 6 }} onPressEnter={this.enterPress}/>)}
            </Form.Item>
          </Col>
        </Row>
      </Form>
    )
  }
}

export default Form.create()(MainSearch)